@@ -347,10 +347,10 @@ def _check_duration(total_time, duration):
 
 def _gen_silence(duration):
     return {
-        "note": None,
+        "note": 0,
         "type": "silence",
         "duration": duration,
-        "velocity": None,
+        "velocity": 0,
     }
 
 
